Struct ExtSessionLockManagerV1
pub struct ExtSessionLockManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
used to lock the session
This interface is used to request that the session be locked.
This interface has no events.
Implementations
impl ExtSessionLockManagerV1
impl ExtSessionLockManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the session lock manager object
This informs the compositor that the session lock manager object will no longer be used. Existing objects created through this interface remain valid.
pub fn lock<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> ExtSessionLockV1
pub fn lock<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> ExtSessionLockV1
attempt to lock the session
This request creates a session lock and asks the compositor to lock the session. The compositor will send either the ext_session_lock_v1.locked or ext_session_lock_v1.finished event on the created object in response to this request.